@@ -20,9 +20,36 @@ def init_args_parser() -> ap.ArgumentParser:
     )
 
     parser.add_argument(
-        'template_name',
+        'mongodb_url',
         type=str,
-        help='template of software requirements specification structure according to which the parsing is performed'
+        help='MongoDB database connection string'
+    )
+
+    parser.add_argument(
+        'db_name',
+        type=str,
+        help='MongoDB database name'
+    )
+
+    parser.add_argument(
+        'tmpl_coll_name',
+        type=str,
+        help='name of MongoDB collection with templates of software requirements specifications structures'
+    )
+
+    parser.add_argument(
+        'tmpl_name',
+        type=str,
+        help='template name of software requirements specification structure '
+             'according to which the parsing is performed'
+    )
+
+    parser.add_argument(
+        'results_coll_name',
+        type=str,
+        help='name of MongoDB collection with parsing results '
+             '(contains software requirements specifications structures '
+             'filled according to the templates of the SRS structures)'
     )
 
     return parser
@@ -32,18 +59,18 @@ def main():
     parser = init_args_parser()
     args = parser.parse_args()
 
-    client = MongoClient(configs.MONGODB_URL)
-    db = client[configs.DB_NAME]
+    client = MongoClient(args.mongodb_url)
+    db = client[args.db_name]
 
-    tmpl_coll = db[configs.TMPL_COLL_NAME]
-    tree_template = tmpl_coll.find_one({'name': args.template_name})['structure']
+    tmpl_coll = db[args.tmpl_coll_name]
+    tree_template = tmpl_coll.find_one({'name': args.tmpl_name})['structure']
 
     parser = SRSParser(tree_template)
     document_structure = parser.parse_docx(args.docx_path)
 
     document_name = splitext(basename(args.docx_path))[0]
 
-    results_coll = db[configs.RESULTS_COLL_NAME]
+    results_coll = db[args.results_coll_name]
     results_coll.insert_one({'document_name': document_name, 'structure': document_structure})
 
     client.close()
